# Changelog

All notable changes to VPN Monitor will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.0] - 2025-12-04

### 🚀 Features

- Implement initial VPN monitor application with Tkinter GUI, sys… ([#8](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/8)) by @henrykp in [#8](https://github.com/henrykp/vpn_status_monitor/pull/8)
- Sign binaries by @henrykp

### 🐛 Bug Fixes

- Pre-commit hooks by @henrykp

### 📚 Documentation

- Update CHANGELOG.md for v0.7.0 by @henrykp
- Update CHANGELOG.md for v1.0.0 by @henrykp

### ⚙️ CI/CD

- **deps:** Bump the github-actions group with 4 updates ([#7](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/7)) by @dependabot[bot] in [#7](https://github.com/henrykp/vpn_status_monitor/pull/7)

## [0.7.0] - 2025-11-29

### 🐛 Bug Fixes

- Supporting docs by @henrykp
- Merge conflict by @henrykp

### 📚 Documentation

- Update CHANGELOG.md for v0.6.0 by @henrykp

## [0.6.0] - 2025-11-29

### 🚀 Features

- Publish to pypi ([#6](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/6)) by @henrykp in [#6](https://github.com/henrykp/vpn_status_monitor/pull/6)

### 🐛 Bug Fixes

- Add PyPI publish by @henrykp
- Merge conflict by @henrykp

### 📚 Documentation

- Update CHANGELOG.md for v0.5.0 by @henrykp

## [0.5.0] - 2025-11-28

### 🚀 Features

- Fix build ([#5](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/5)) by @henrykp in [#5](https://github.com/henrykp/vpn_status_monitor/pull/5)

### 🐛 Bug Fixes

- Fix linter issues ([#3](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/3)) by @henrykp in [#3](https://github.com/henrykp/vpn_status_monitor/pull/3)

### 📚 Documentation

- Update CHANGELOG.md for v0.4.0 by @henrykp

### ⚙️ CI/CD

- **deps:** Bump the github-actions group with 7 updates ([#1](https://github.com/{{ remote.github.owner }}/{{ remote.github.repo }}/issues/1)) by @dependabot[bot] in [#1](https://github.com/henrykp/vpn_status_monitor/pull/1)

## [0.2.0] - 2025-11-28

### 🚀 Features

- First commit by @henrykp

<!-- generated by git-cliff -->
